.. _server:

***********************************************************************
Classes representing Identity Provider or Attribute Authority instances
***********************************************************************

:Author: Roland Hedberg
:Version: |version|

.. module:: IdPAA
   :synopsis: Classes representing Identity Provider or Attribute 
                Authority instances.

Module
======

.. automodule:: saml2.server
   :members: 

